@@ -73,8 +73,8 @@ class Query
         $this->text = $text;          // content or search term
         $this->dateFrom = $dateFrom;
         $this->dateTo = $dateTo;
-        $this->sender = $sender;
-        $this->recipient = $recipient;
+        $this->sender = trim($sender);
+        $this->recipient = trim($recipient);
         $this->subject = $subject;
         $this->headerName = $headerName;        // only in extended search
         $this->headerValue = $headerValue;
