@@ -91,7 +91,7 @@ class User extends UserDA
      * Authorization level:
      *     ADMIN    16
      *     REVISOR   4
-     *     USER      1
+     *     USER      2
      *
      * @access public
      * @var string
@@ -99,6 +99,20 @@ class User extends UserDA
     var $role;
 
 
+   /**
+     * restdata
+     *
+     * Information about REST backend
+     *  rest['URL']
+     *  rest['USER']
+     *  rest['PASS']
+     *
+     * @access public
+     * @var array
+     */
+    var $restdata;
+
+
     /**
      * constructor
      *
@@ -109,9 +123,10 @@ class User extends UserDA
      * @param string $archive optional
      * @param string $role optional
      * @param array $addresses optional
+     * @param array $restdata optional
      * @return object
      */
-    function User ($id,$password='',$name='',$archive=array(),$role='',$adresses=array())
+    function User ($id,$password='',$name='',$archive=array(),$role='',$adresses=array(),$restdata=array())
     {
         $this->id = $id;
         $this->password = $password;
@@ -119,12 +134,13 @@ class User extends UserDA
         $this->archive = $archive;
         $this->role = $role;
         $this->addresses = $adresses;
+        $this->restdata= $restdata;
     }
 
     function getAuthzLevel () {
         if ($this->role == 'ADMIN')   { return 16; }
         if ($this->role == 'REVISOR') { return 4; }
-        if ($this->role == 'USER')    { return 1; }
+        if ($this->role == 'USER')    { return 2; }
     }
 
     function setPassword ($pass) { $this->password = $password; }
@@ -138,5 +154,7 @@ class User extends UserDA
     function getAdresses () { return $this->adresses; }
     function setAdresses ($adresses) { $this->adresses = $adresses; }
 
+    function setRestData ($restdata) { $this->restdata = $restdata; }
+    function getRestData () { return $this->restdata; }
 }
 ?>
