@@ -58,6 +58,10 @@ $MailObject->bcc        = $EMail->getBcc();
 $MailObject->subject    = $EMail->getSubject();
 $MailObject->verified   = $EMail->isVerified();
 
+if ($USER->role == 'ADMIN') {
+    $MailObject->bennoId    = $EMail->bennoId;
+}
+
 $atm_list = array();
 foreach ($EMail->getAttachments() as $Attachment) {
     $atm['id']           = urlencode($Attachment->id);
